geowatch.cli.baseline\_framework\_ingress module
================================================

.. automodule:: geowatch.cli.baseline_framework_ingress
   :members:
   :undoc-members:
   :show-inheritance:
